-- Author: VertexFloat
-- Date: 11.12.2021
-- Version: Farming Simulator 22, 1.0.0.0
-- Copyright (C): VertexFloat, All Rights Reserved
-- Handling Combine Discharge Context HUD for Manual Combine Discharge

local modDirectory = g_currentModDirectory

ManualCombineDischargeHUD = {}

local ManualCombineDischargeHUD_mt = Class(ManualCombineDischargeHUD)

function ManualCombineDischargeHUD:new(mission, inputDisplayManager, contextActionDisplay)
	local self = setmetatable({}, ManualCombineDischargeHUD_mt)
	
	self.mission = mission
	self.isClient = mission:getIsClient()
	self.contextActionDisplay = contextActionDisplay
	self.hudAtlasPath = Utils.getFilename("src/resources/hud/hud_element.dds", modDirectory)
	
	self.uiScale = g_gameSettings:getValue("uiScale")
	
	self.context = CombineDischargeContext.new(self.hudAtlasPath, inputDisplayManager)
	self.context:setScale(self.uiScale)
	
	return self
end

function ManualCombineDischargeHUD:update(dt)
	if not self.isClient then
		return
	end
	
	self.context:update(dt)
end

function ManualCombineDischargeHUD:draw()
	local vehicle = g_currentMission.controlledVehicle
	
	if vehicle ~= nil then
		if SpecializationUtil.hasSpecialization(Combine, vehicle.specializations) then
			local spec = vehicle.spec_manualCombineDischarge
			local fillTypeIndex = vehicle:getFillUnitFillType(1)
			local fillType = g_fillTypeManager:getFillTypeByIndex(fillTypeIndex)
			
			if spec.isActionAllowed and not g_gui:getIsGuiVisible() and not g_noHudModeEnabled and self:getCanDraw() then
				self.context:setContext(InputAction.TOGGLE_DISCHARGE_PIPE, CombineDischargeContext.CONTEXT_ICON.DISCHARGE, fillType.title)
			end
		end
	end
	
	self.context:draw()
end

function ManualCombineDischargeHUD:getCanDraw()
	if self.contextActionDisplay ~= nil then
		local isVisibleOld = self.contextActionDisplay:getVisible()
		
		if isVisibleOld then
			return false
		end
	end
	
	return true
end

function ManualCombineDischargeHUD:delete()
	self.context:delete()
end